#!/usr/bin/env python
import LSD, gzip
import pandas as pd, numpy as np
from os.path import expanduser, exists
from itertools import count
from LSD import storeDatasetLocally, datadir, Dataset

def get_NB39():
    """
    39 neuroblastoma cell lines + RPE1 and HU.FETAL.BRAIN

    Reference: https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE89413
    Source: https://www.ncbi.nlm.nih.gov/geo/download/?acc=GSE89413&format=file&\
file=GSE89413%5F2016%2D10%2D30%2DNBL%2Dcell%2Dline%2DSTAR%2Dfpkm%2Etxt%2Egz
    """
    exprdata = pd.read_table(
        gzip.open(
            datadir+'GEO/NB39_celllines_Maris/GSE89413_2016-10-30-NBL-cell-line-STAR-fpkm.txt.gz',
            'rt',encoding='UTF-8'
        ),
        index_col='GeneID'
    )

    return Dataset(exprdata=exprdata)

def get_CCLE():
    """
    Reference: https://portals.broadinstitute.org/ccle
    """
    metadata = pd.read_table(datadir+'CCLE/CCLE_sample_info_file_2012-10-18.txt',index_col='CCLE name')
    exprdata = pd.read_table(datadir+'CCLE/CCLE_Expression_Entrez_2012-09-29.gct',skiprows=2,index_col='Description')
    return Dataset(exprdata=exprdata,metadata=metadata)



#!/usr/bin/env python
import LSD
import pandas as pd, numpy as np
from rpy2.robjects.packages import importr
import rpy2.robjects as ro

#Activate automatic pandas/r conversion
from rpy2.robjects import pandas2ri
pandas2ri.activate()

@LSD.storeDatasetLocally
def get_THMYCN():
    """
    Source: ~/Dropbiz/Lab/z_archive/Datasets/2015_Hyperplasia_ABC/uniData.tx
    Source: ~/Dropbiz/Lab/z_archive/Datasets/2015_Hyperplasia_ABC/SampleAnnotation.txt
    """
    #TH-MYCN mouse model incorporation
    importr('limma')
    importr('preprocessCore')
    thannot = pd.read_table(LSD.datadir+'2015_Hyperplasia_ABC/SampleAnnotation.txt')
    thannot.group = thannot.group.apply(lambda x: x.replace('.','_'))
    thdata = pd.read_table(LSD.datadir+'2015_Hyperplasia_ABC/uniData.txt',sep=' ')
    thdata.columns = thannot.group + (['_r'+str(i+1) for i in range(4)]*3*2)
    genotype = thannot.genotype
    age = thannot.age
    ro.globalenv["thdata"] = thdata
    ro.globalenv["genotype"] = ro.r.relevel(ro.FactorVector(genotype),ref='WT')
    ro.globalenv["age"] = ro.IntVector(age)
    ro.r('thdatanorm <- normalize.quantiles(as.matrix(thdata))')
    ro.r('colnames(thdatanorm) <- colnames(thdata)')
    ro.r('rownames(thdatanorm) <- rownames(thdata)')
    ro.r('designSamples = model.matrix(formula(~genotype:age))')
    ro.r('colnames(designSamples)')
    ro.r('fit <- lmFit(thdatanorm,designSamples)')
    ro.r('fit <- eBayes(fit)')
    thcoeffs = ro.r('data.frame(fit$coefficients)')
    thcoeffs['lineardiff'] = thcoeffs['genotypeTG.age']-thcoeffs['genotypeWT.age']

    return LSD.Dataset(exprData=thdata,
                       metadata=thannot,
                       lmCoeffs=thcoeffs)
